abacusai.organization_external_application_settings — AbacusAI documentation

# `abacusai.organization_external_application_settings`

## Module Contents

### Classes

`OrganizationExternalApplicationSettings` | The External Application Settings for an Organization.

class abacusai.organization_external_application_settings.OrganizationExternalApplicationSettings(client, logo=None, theme=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The External Application Settings for an Organization.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - logo (str) – The logo.

    - theme (dict) – The theme used for External Applications in this org.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict